#!/usr/bin/python
# -*- coding: utf-8 -*-

### GAD PIPELINE ###
## rename_fastq.py
## Description: Renames fastq files (format sampleID.R?.fastq.gz)
## Usage: python rename_fastq.py -d </working/directory> -f <format (supported: miseq, wes)>
## Output: renamed fastq.gz files (format: sampleID.R?.fastq.gz)
## Requirements: python 2.7+, LabkeyTools, GeneralTools

## Author: jbjriviere@gmail.com , emilie.tisserant@u-bourgogne.fr , yannis.duffourd@u-bourgogne.fr
## Creation Date: 20150814
## last revision date: 20191203
## Known bugs:	Only works in a directory with fastq files
##		Only works with compressed fastq (.fastq.gz)
##		Formats are hardcoded (miseq, integragen, cng). If different, new formats must be added to the script.


import sys
import os
import re
import logging

from GeneralTools import Argms
from LabkeyTools import GetRows


usage = """
Usage:		python rename_fastq.py -d </working/directory> -f <format (supported: miseq, wes)> -e logfile
Commands	-d	<optional> Directory of fastq files (current directory if not provided)
		-f	Format (supported formats: miseq, wes)
Example:	python rename_fastq.py -f miseq
Caveats:	Only works in a directory with fastq files
		Only works with compressed fastq (.fastq.gz)
		Formats are hard-coded (miseq, integragen, cng). If different, new formats must be added to the script
"""


# Definitions
def MatchList(mylist, regex):
	"""Returns a list of items from mylist matching the provided regular expression"""
	rec = []
	for i in mylist:
		if regex.findall(i) == [i]:
			rec.append(i)
	return rec


# Arguments
argm = Argms('d:f:e:h')


# Print usage
if "-h" in argm:
	sys.exit(usage)

if "-e" in argm:
	logpath = argm["-e"]
else:
    logpath = argm["-d"]+"/rename_fastq.log"


# Logging
logging.basicConfig(filename =  '%s' % (logpath), filemode = 'a', level = logging.INFO, format = '%(asctime)s %(levelname)s - %(message)s')

logging.info('start')

# Define working directory
try:
	workdir = argm["-d"]
except KeyError:
	workdir = "."

if workdir == "/" or workdir == "//":
	logging.exception("'/' and '//' are not supported directories")
	sys.exit(1)

if not os.path.exists(workdir):
	logging.exception("%s\nError: directory %s doesn't exist" % (usage, workdir))
	sys.exit(1)


# Define format
try:
	form = argm["-f"]
except KeyError:
	logging.exception("%s\n%s" % (usage, "Error: no format was given"))
	sys.exit(1)

# Define supported formats
formats = ["miseq", "wes" , "rna"]
if not form in formats:
	logging.exception("%s\nError: format %s is not supported" % (usage, form))
	sys.exit(1)

# Generate list of fastq files & samples
fastqs = [f for f in os.listdir(workdir) if f.endswith("fastq.gz")]

if len(fastqs) == 0:
	logging.exception("%s\n%s %s" % (usage, "Error: no fastq files in working directory", workdir))
	sys.exit(1)

# MiSeq format
if form == "miseq":

	# Do nothing if fastq files in right format
	regex = re.compile(r"^.*\.R[12]\.fastq\.gz$")
	files = MatchList(fastqs, regex)
	if fastqs == files:
		for f in files:
			logging.info("%s %s" % (f, "is in the right format"))
		sys.exit(0)

	# If not, rename fastqs
	else:
		regex = re.compile(r"^.*\_S[0-9]*_L[0-9]*_R[12]_[0-9]*\.fastq.gz$")
		files = MatchList(fastqs, regex)

		if fastqs == files:
			# Dictionary with original filenames as keys and new filenames as values
			names = {f:"%s.%s.fastq.gz" % (f.split("_")[0], f.split("_")[3]) for f in files}
			for key in names.keys():
				logging.info(key+"\t"+names[key])
				os.rename("%s/%s" % (workdir, key), "%s/%s" % (workdir, names[key]))

		# If the number of fastq files doesn't match the number of files to rename
		else:
			open("rename_fastq.failed", 'w').close()
			logging.exception("Error: someting went wrong\nError: below is a list of fastq files in %s" % (workdir))
			for f in fastqs:
				logging.exception(f)
			sys.exit(1)
#RNASeq
elif form == "rna":
# Do nothing if fastq files in right format
	regex = re.compile(r"dijarn[0-9]*\.R[12]\.fastq\.gz$")
	files = MatchList(fastqs, regex)
	if fastqs == files:
		for f in files:
			logging.info("%s %s" % (f, "is in the right format"))
		sys.exit(0)
	if form == "rna":
		# Integragen format
		logging.info("Try integragen file name format")
		regex = re.compile(r"^[0-9]*\_R[12].fastq.gz$")
		files = MatchList(fastqs, regex)
		tag = 0
		if fastqs != files:
			logging.warning("File name format does not match with integragen format")
			tag = 1
		else:
			# Generate a dictionary with sampleID (GAD) as key and list of associated dijexIDs as value
			samples = list(set([f.split("_")[0].lower() for f in fastqs]))
			exomes = GetRows("Suivi exomes")["rows"]
			logging.info(" Size of exomes : %s\n" % len( exomes ) )
			gad = {}
			for sample in samples:
				gad[sample] = [l["dijexID"] for l in exomes if (sample == str(l["SpecimenID"]) or sample == str(l["dijexID"])) and l["statut"] != "Echec CQ" and l["statut"] != "Annulé"]
				gad[sample] = list(set(gad[sample]))
				if len(gad[sample]) == 0:
					logging.exception("Sample %s not found in Suivi exomes" % (sample))
					sys.exit(1)
			# Dictionary with original filenames as keys and new filenames as values
			names = {f:"%s.%s.fastq.gz" % (gad[f.split("_")[0].lower()][0], f.split("_")[1].split(".")[0]) for f in files}
			for key in names.keys():
				logging.info(key+"\t"+names[key])
				os.rename("%s/%s" % (workdir, key), "%s/%s" % (workdir, names[key]))

		if tag == 1:
			# Genewiz format
			logging.info("Try GeneWiz file name format")
			regex = re.compile(r"^[0-9]*\_R[12]_[0-9]*.fastq.gz$")
			files = MatchList(fastqs, regex)
			if fastqs != files:
				logging.warning("File name format does not match GeneWiz format")
				tag = 2
			else:
				# Generate a dictionary with sampleID (GAD) as key and list of associated dijexIDs as value
				samples = list(set([f.split("_")[0] for f in fastqs]))
				exomes = GetRows("Suivi exomes")["rows"]
				logging.info(" Size of exomes : %s\n" % len( exomes ) )
				gad = {}
				for sample in samples:
					gad[sample] = [l["dijexID"] for l in exomes if sample == str(l["SpecimenID"]) and l["statut"] != "Echec CQ" and l["statut"] != "Annulé"]
					gad[sample] = list(set(gad[sample]))
					if len(gad[sample]) > 1:
						logging.exception("Error: sample %s found %s times in Suivi exomes: %s" % (sample, len(gad[sample]), ", ".join(gad[sample])))
						sys.exit(1)
					elif len(gad[sample]) == 0:
						logging.exception("Sample %s not found in Suivi exomes" % (sample))
						sys.exit(1)
				# Dictionary with original filenames as keys and new filenames as values
				names = {f:"%s.%s.fastq.gz" % (gad[f.split("_")[0]][0], f.split("_")[1]) for f in files}
				for key in names.keys():
					logging.info(key+"\t"+names[key])
					os.rename("%s/%s" % (workdir, key), "%s/%s" % (workdir, names[key]))

		if tag == 2:
			# CNG format
			logging.info("Try CNG file name format")
			#regex = re.compile(r"[A-Za-z0-9]*_[A-Za-z0-9]*_[A-Za-z0-9]{7}_[0-9]{1}_[12]_[A-Za-z0-9]{9}.[A-Za-z0-9]*.fastq.gz$")
			regex = re.compile(r"[A-Za-z0-9]*.R[12].fastq.gz$")
			files = MatchList(fastqs, regex)
			if fastqs != files:
				logging.exception("File name format does not match with CNG format")
				sys.exit(1)
			else:
				# Generate a dictionary with sampleID (GAD) as key and list of associated dijexIDs as value
				samples = list(set([f.split(".")[0] for f in fastqs]))
				exomes = GetRows("Suivi exomes")["rows"]
				gad = {}
				for sample in samples:
					gad[sample] = [l["dijexID"] for l in exomes if sample == str(l["aliasID"]) and l["statut"] != "Echec CQ"]
					gad[sample] = list(set(gad[sample]))
					if len(gad[sample]) > 1:
						logging.exception("Error: sample %s found %s times in Suivi exomes: %s" % (sample, len(gad[sample]), ", ".join(gad[sample])))
						sys.exit(1)
					elif len(gad[sample]) == 0:
						logging.exception("Sample %s not found in Suivi exomes" % (sample))
						sys.exit(1)
				# Dictionary with original filenames as keys and new filenames as values
				#names = {f:"%s.%s.fastq.gz" % (gad[f.split("_")[2]][0], "R"+f.split("_")[4]) for f in files}
				names = {f:"%s.%s.fastq.gz" % (gad[f.split(".")[0]][0], f.split(".")[1]) for f in files}
				for key in names.keys():
					logging.info(key+"\t"+names[key])
					os.rename("%s/%s" % (workdir, key), "%s/%s" % (workdir, names[key]))

# WES
else:
	# Do nothing if fastq files in right format
	regex = re.compile('('+r"dije[xn][0-9]*\.R[12]\.fastq\.gz$"+'|'+r"[Pp]ool[pm]ere[0-9]*\.R[12]\.fastq\.gz$"+')')
	files = MatchList(fastqs, regex)
	if fastqs == files:
		for f in files:
			logging.info("%s %s" % (f, "is in the right format"))
		sys.exit(0)

	if form == "wes":
		# Integragen format
		logging.info("Try integragen file name format")
		regex = re.compile('('+r"^[0-9]*\_R[12].fastq.gz$"+'|'+r"[Pp]ool[pm]ere[0-9]*\_R[12]\.fastq\.gz$"+')')
		files = MatchList(fastqs, regex)
		tag = 0
		if fastqs != files:
			logging.warning("File name format does not match with integragen format")
			tag = 1
		else:
			# Generate a dictionary with sampleID (GAD) as key and list of associated dijexIDs as value
			samples = list(set([f.split("_")[0].lower() for f in fastqs]))
			exomes = GetRows("Suivi exomes")["rows"]
			logging.info(" Size of exomes : %s\n" % len( exomes ) )
			gad = {}
			for sample in samples:
				gad[sample] = [l["dijexID"] for l in exomes if (sample == str(l["SpecimenID"]) or sample == str(l["dijexID"])) and l["statut"] != "Echec CQ"]
				gad[sample] = list(set(gad[sample]))
				if len(gad[sample]) > 1:
					logging.exception("Error: sample %s found %s times in Suivi exomes: %s" % (sample, len(gad[sample]), ", ".join(gad[sample])))
					sys.exit(1)
				elif len(gad[sample]) == 0:
					logging.exception("Sample %s not found in Suivi exomes" % (sample))
					sys.exit(1)
			# Dictionary with original filenames as keys and new filenames as values
			names = {f:"%s.%s.fastq.gz" % (gad[f.split("_")[0].lower()][0], f.split("_")[1].split(".")[0]) for f in files}
			for key in names.keys():
				logging.info(key+"\t"+names[key])
				os.rename("%s/%s" % (workdir, key), "%s/%s" % (workdir, names[key]))

		if tag == 1:
			# Integragen old format
			logging.info("Try integragen old file name format")
			regex = re.compile(r"^Sample_.*\_R[12]_fastq.gz$")
			files = MatchList(fastqs, regex)
			if fastqs != files:
				logging.warning("File name format does not match with integragen old format")
				tag = 2
			else:
				# Generate a dictionary with sampleID (GAD) as key and list of associated dijexIDs as value
				samples = list(set([f.split("_")[1] for f in fastqs]))
				exomes = GetRows("Suivi exomes")["rows"]
				logging.info(" Size of exomes : %s\n" % len( exomes ) )
				gad = {}
				for sample in samples:
					gad[sample] = [l["dijexID"] for l in exomes if sample == str(l["SpecimenID"]) and l["statut"] != "Echec CQ"]
					gad[sample] = list(set(gad[sample]))
					if len(gad[sample]) > 1:
						logging.exception("Error: sample %s found %s times in Suivi exomes: %s" % (sample, len(gad[sample]), ", ".join(gad[sample])))
						sys.exit(1)
					elif len(gad[sample]) == 0:
						logging.exception("Sample %s not found in Suivi exomes" % (sample))
						sys.exit(1)
				# Dictionary with original filenames as keys and new filenames as values
				names = {f:"%s.%s.fastq.gz" % (gad[f.split("_")[1]][0], f.split("_")[2]) for f in files}
				for key in names.keys():
					logging.info(key+"\t"+names[key])
					os.rename("%s/%s" % (workdir, key), "%s/%s" % (workdir, names[key]))

		if tag == 2:
			# CNG format
			logging.info("Try CNG file name format")
			#regex = re.compile(r"[A-Za-z0-9]*_[A-Za-z0-9]*_[A-Za-z0-9]{7}_[0-9]{1}_[12]_[A-Za-z0-9]{9}.[A-Za-z0-9]*.fastq.gz$")
			regex = re.compile(r"[A-Za-z0-9]*.R[12].fastq.gz$")
			files = MatchList(fastqs, regex)
			if fastqs != files:
				logging.exception("File name format does not match with CNG format")
				sys.exit(1)
			else:
				# Generate a dictionary with sampleID (GAD) as key and list of associated dijexIDs as value
				samples = list(set([f.split(".")[0] for f in fastqs]))
				exomes = GetRows("Suivi exomes")["rows"]
				gad = {}
				for sample in samples:
					gad[sample] = [l["dijexID"] for l in exomes if sample == str(l["aliasID"]) and l["statut"] != "Echec CQ"]
					gad[sample] = list(set(gad[sample]))
					if len(gad[sample]) > 1:
						logging.exception("Error: sample %s found %s times in Suivi exomes: %s" % (sample, len(gad[sample]), ", ".join(gad[sample])))
						sys.exit(1)
					elif len(gad[sample]) == 0:
						logging.exception("Sample %s not found in Suivi exomes" % (sample))
						sys.exit(1)
				# Dictionary with original filenames as keys and new filenames as values
				#names = {f:"%s.%s.fastq.gz" % (gad[f.split("_")[2]][0], "R"+f.split("_")[4]) for f in files}
				names = {f:"%s.%s.fastq.gz" % (gad[f.split(".")[0]][0], f.split(".")[1]) for f in files}
				for key in names.keys():
					logging.info(key+"\t"+names[key])
					os.rename("%s/%s" % (workdir, key), "%s/%s" % (workdir, names[key]))
logging.info('end')
